import logging

from django.urls import path

from . import views

logger = logging.getLogger(__name__)

app_name = "order"
urlpatterns = [
    path("commande/", views.IndexView.as_view(), name="index"),
    path(
        "commande/<str:code>/",
        views.GroupedOrderDetailView.as_view(),
        name="grouped_order_detail",
    ),
    path(
        "commande/<str:code>/ics/",
        views.GroupedOrderEventView.as_view(),
        name="grouped_order_event",
    ),
    path(
        "commande/<str:code>/gerer",
        views.GroupedOrderOverview.as_view(),
        name="grouped_order_overview",
    ),
    path("commande/<str:code>/commander/", views.place_order, name="order"),
    path(
        "commande/<str:code>/<int:pk>/confirmation/",
        views.OrderDetailView.as_view(),
        name="order_confirm",
    ),
    path(
        "commande/<str:code>/gerer/<int:pk>/supprimer",
        views.OrderDeleteView.as_view(),
        name="order_delete",
    ),
    path(
        "commande/creer",
        views.GroupedOrderCreateView.as_view(),
        name="create_grouped_order",
    ),
    path(
        "commande/<str:code>/gerer-produits",
        views.GroupedOrderAddItemsView.as_view(),
        name="manage_items",
    ),
    path(
        "commande/<str:code>/modifier",
        views.GroupedOrderUpdateView.as_view(),
        name="update_grouped_order",
    ),
    path(
        "commande/<str:code>/supprimer",
        views.GroupedOrderDeleteView.as_view(),
        name="delete_grouped_order",
    ),
    path(
        "commande/<str:code>/dupliquer",
        views.GroupedOrderDuplicateView.as_view(),
        name="duplicate_grouped_order",
    ),
    path(
        "commande/<str:code>/gerer-produits/nouveau",
        views.ItemCreateView.as_view(),
        name="item_create",
    ),
    path(
        "commande/<str:code>/gerer-produits/<int:pk>/supprimer",
        views.ItemDeleteView.as_view(),
        name="item_delete",
    ),
    path(
        "commande/<str:code>/gerer/imprimer",
        views.DownloadGroupedOrderSheetView.as_view(),
        name="grouped_order_sheet",
    ),
    path(
        "commande/<str:code>/gerer/liste-mails",
        views.ExportGroupOrderEmailAdressesToDownloadView.as_view(),
        name="email_list",
    ),
    path(
        "commande/<str:code>/gerer/csv",
        views.ExportGroupedOrderToCSVView.as_view(),
        name="grouped_order_csv_export",
    ),
    path("lieu/", views.PlaceIndexView.as_view(), name="place_index"),
    path(
        "lieu/<str:code>/modifier",
        views.PlaceUpdateView.as_view(),
        name="place_update",
    ),
    # TODO: It's not great that we reserve special keywords as we go
    # It would be better to use different HTTP verbs, or have a predefined
    # list of reserved keywords, or use an entirely different route...
    path("lieu/creer", views.PlaceCreateView.as_view(), name="place_create"),
    path(
        "lieu/<str:code>",
        views.PlaceOverviewView.as_view(),
        name="place_overview",
    ),
]
